import { 
  select, 
  csv, 
  scaleLinear, 
  extent,  
  axisLeft,
  axisBottom
} from 'd3';

export const scatterPlot = (selection, props) => {
	const {
    xValue,
  	xAxisLabel,
  	yValue,
  	yAxisLabel,
    circleRadius,
  	margin,
  	width,
  	height,
  	data} = props;
		
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([innerHeight, 0])
  	.nice();
 
  
  const yAxis = axisLeft(yScale)
  							.tickSize(-innerWidth)
  							.tickPadding(5);
  
  const xAxis = axisBottom(xScale)
  								.tickSize(-innerHeight)
  								.tickPadding(20);
 
  
  const g = selection.selectAll('.container').data([null]);
  
  const gEnter = g.enter().append('g').attr('class', 'container');
  
  gEnter.merge(g)
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
	const yAxisG = g.select('.y-axis');
  const yAxisGenter = gEnter.append('g')
  			.attr('class', 'y-axis');
  yAxisG
  		.merge(yAxisGenter)
  			.call(yAxis)
  			.selectAll('.domain').remove();
  
  const yAxisLabelText = yAxisGenter.append('text')
  	.attr('class', 'axis-label')
  	.attr('fill', 'black')
  	.attr('y', -93)
  	.attr('text-anchor', 'middle')
  	.attr('transform', `rotate(-90)`)
  .merge(yAxisG.select('.axis-label'))	
  	.attr('x', -innerHeight/2)
  	.text(yAxisLabel);
  
  
  const xAxisG = g.select('.x-axis');
  const xAxisGenter = gEnter.append('g')
  			.attr('class', 'x-axis');
  xAxisG
  		.merge(xAxisGenter)
  			.attr('transform', `translate(0, ${innerHeight})`)
  			.call(xAxis)
  			.selectAll('.domain').remove();
  
  const xAxisLabelText = xAxisGenter.append('text')
  	.attr('class', 'axis-label')
  	.attr('fill', 'black')
  	.attr('y', 60)
  	.attr('text-anchor', 'middle')
  .merge(xAxisG.select('.axis-label'))	
  	.attr('x', innerWidth/2)
  	.text(xAxisLabel);
   
	const circles = g.merge(gEnter).selectAll('circle').data(data);
  circles.enter().append('circle')
    	.attr('cx', innerWidth / 2)
  		.attr('cy', innerHeight / 2)
  		.attr('r', 0)
    .merge(circles)
  		.transition().duration(1000)
    	.delay((d,i) => i * 10)
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('cx', d => xScale(xValue(d)))
  		.attr('r', circleRadius);
  
}